#[repr(transparent)]pub struct Cap(pub u32);Expand description
Capture register .
Tuple Fields
0: u32Implementations
Sourceimpl Cap
impl Cap
Sourcepub const fn cap_value(&self) -> u32
pub const fn cap_value(&self) -> u32
Capture value for the related capture event (UTICK_CAPn. Note: the value is 1 lower than the actual value of the Micro-tick Timer at the moment of the capture event.
Sourcepub const fn set_cap_value(&mut self, val: u32)
pub const fn set_cap_value(&mut self, val: u32)
Capture value for the related capture event (UTICK_CAPn. Note: the value is 1 lower than the actual value of the Micro-tick Timer at the moment of the capture event.