nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Stat

Struct Stat 

#[repr(transparent)]
pub struct Stat(pub u32);
Status register.

Tuple Fields

0: u32

Implementations

Source

impl Stat

pub const fn intr(&self) -> bool

Interrupt flag. 0 = No interrupt is pending. 1 = An interrupt is pending. A write of any value to this register clears this flag.

pub const fn set_intr(&mut self, val: bool)

Interrupt flag. 0 = No interrupt is pending. 1 = An interrupt is pending. A write of any value to this register clears this flag.

pub const fn active(&self) -> bool

Active flag. 0 = The Micro-Tick Timer is stopped. 1 = The Micro-Tick Timer is currently active.

pub const fn set_active(&mut self, val: bool)

Active flag. 0 = The Micro-Tick Timer is stopped. 1 = The Micro-Tick Timer is currently active.